@@ -5,8 +5,12 @@ use namespace::autoclean;
 
 with 'XML::NewsML_G2::Role::HasQCode';
 
-has 'translations', isa => 'HashRef', is => 'rw', default => sub { {} }, traits => ['Hash'],
-  handles => {add_translation => 'set'};
+has 'translations',
+    isa     => 'HashRef',
+    is      => 'rw',
+    default => sub { {} },
+    traits  => ['Hash'],
+    handles => { add_translation => 'set' };
 has 'parent', isa => __PACKAGE__, is => 'rw';
 has 'direct', isa => 'Bool', is => 'rw', default => '';
 
